@@ -1,6 +1,6 @@
 /*
  * music player command (mpc)
- * Copyright (C) 2003-2015 The Music Player Daemon Project
+ * Copyright (C) 2003-2017 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -149,160 +149,6 @@ cmd_toggle(gcc_unused int argc, gcc_unused char **argv,
 	return 1;
 }
 
-int
-cmd_outputs(gcc_unused int argc, gcc_unused char **argv,
-	    struct mpd_connection *conn)
-{
-	mpd_send_outputs(conn);
-
-	struct mpd_output *output;
-	while ((output = mpd_recv_output(conn)) != NULL) {
-		/* We increment by 1 to make it natural to the user  */
-		int id = mpd_output_get_id(output) + 1;
-		const char *name = mpd_output_get_name(output);
-
-		if (mpd_output_get_enabled(output)) {
-			printf("Output %i (%s) is enabled\n", id, name);
-		} else {
-			printf("Output %i (%s) is disabled\n", id, name);
-		}
-
-		mpd_output_free(output);
-	}
-
-	my_finishCommand(conn);
-	return 0;
-}
-
-static unsigned
-match_outputs(struct mpd_connection *conn,
-	      char **names, char **names_end, unsigned **ids_end)
-{
-	unsigned max = 0, *id = *ids_end;
-
-	mpd_send_outputs(conn);
-
-	struct mpd_output *output;
-	while ((output = mpd_recv_output(conn)) != NULL) {
-		const char *name = mpd_output_get_name(output);
-		max = mpd_output_get_id(output);
-
-		for (char **n = names; n != names_end; ++n) {
-			if (!strcmp(*n, name)) {
-				*id = max;
-				++id;
-				*n = *names;
-				++names;
-				break;
-			}
-		}
-
-		mpd_output_free(output);
-	}
-
-	my_finishCommand(conn);
-
-	for (char **n = names; n != names_end; ++n) {
-		fprintf(stderr, "%s: no such output\n", *n);
-	}
-
-	*ids_end = id;
-	return max;
-}
-
-static int
-enable_disable(int argc, char **argv, struct mpd_connection *conn,
-	       bool (*matched)(struct mpd_connection *conn, unsigned id),
-	       bool (*not_matched)(struct mpd_connection *conn, unsigned id))
-{
-	char **names = argv, **names_end = argv;
-
-	bool only = false;
-	if (not_matched != NULL && !strcmp(argv[0], "only")) {
-		only = true;
-		++argv;
-		if (!--argc) {
-			DIE("No outputs specified.");
-		}
-	}
-
-	unsigned *ids = malloc(argc * sizeof *ids);
-	unsigned *ids_end = ids;
-
-	for (int i = argc; i; --i, ++argv) {
-		int arg;
-		if (!parse_int(*argv, &arg)) {
-			*names_end = *argv;
-			++names_end;
-		} else if (arg <= 0) {
-			fprintf(stderr, "%s: not a positive integer\n", *argv);
-		} else {
-			/* We decrement by 1 to make it natural to the user. */
-			*ids_end++ = arg - 1;
-		}
-	}
-
-	unsigned max;
-	if (only || names != names_end) {
-		max = match_outputs(conn, names, names_end, &ids_end);
-	}
-
-	if (ids == ids_end) {
-		goto done;
-	}
-
-	if (!mpd_command_list_begin(conn, false)) {
-		printErrorAndExit(conn);
-	}
-
-	if (only) {
-		for (unsigned i = 0; i <= max; ++i) {
-			bool found = false;
-			for (unsigned *id = ids;
-			     !found && id != ids_end;
-			     ++id) {
-				found = *id == i;
-			}
-			(found ? matched : not_matched)(conn, i);
-		}
-	} else {
-		for (unsigned *id = ids; id != ids_end; ++id) {
-			matched(conn, *id);
-		}
-	}
-
-	if (!mpd_command_list_end(conn) || !mpd_response_finish(conn)) {
-		printErrorAndExit(conn);
-	}
-
-	cmd_outputs(0, NULL, conn);
-
-done:
-	free(ids);
-	return 0;
-}
-
-int
-cmd_enable(int argc, char **argv, struct mpd_connection *conn)
-{
-	return enable_disable(argc, argv, conn, mpd_send_enable_output,
-			      mpd_send_disable_output);
-}
-
-int
-cmd_disable(gcc_unused int argc, char **argv, struct mpd_connection *conn)
-{
-	return enable_disable(argc, argv, conn, mpd_send_disable_output,
-			      mpd_send_enable_output);
-}
-
-int
-cmd_toggle_output(int argc, char **argv, struct mpd_connection *conn)
-{
-	return enable_disable(argc, argv, conn, mpd_send_toggle_output,
-			      mpd_send_toggle_output);
-}
-
 int
 cmd_play(int argc, char **argv, struct mpd_connection *conn)
 {
@@ -618,7 +464,7 @@ cmd_update(int argc, char **argv, struct mpd_connection *conn)
 		/* is our last queued update finished now? */
 
 		if (current_id == 0 || current_id > id ||
-		    (id > 1 << 30 && id < 1000)) /* wraparound */
+		    (id > (1 << 30) && id < 1000)) /* wraparound */
 			break;
 	}
 
