@@ -1,6 +1,6 @@
 /*
  * music player command (mpc)
- * Copyright (C) 2003-2015 The Music Player Daemon Project
+ * Copyright (C) 2003-2017 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -30,6 +30,7 @@ int cmd_searchplay(int argc, char **argv, struct mpd_connection *conn);
 int cmd_next(int argc, char **argv, struct mpd_connection *conn);
 int cmd_prev(int argc, char **argv, struct mpd_connection *conn);
 int cmd_pause(int argc, char **argv, struct mpd_connection *conn);
+int cmd_pause_if_playing(int argc, char **argv, struct mpd_connection *conn);
 int cmd_stop(int argc, char **argv, struct mpd_connection *conn);
 int cmd_seek(int argc, char **argv, struct mpd_connection *conn);
 int cmd_clearerror(int argc, char **argv, struct mpd_connection *conn);
@@ -49,13 +50,6 @@ int cmd_consume(int argc, char **argv, struct mpd_connection *conn);
 int cmd_crossfade(int argc, char **argv, struct mpd_connection *conn);
 int cmd_mixrampdb(int argc, char **argv, struct mpd_connection *conn);
 int cmd_mixrampdelay(int argc, char **argv, struct mpd_connection *conn);
-int cmd_enable( int argc, char **argv, struct mpd_connection *conn);
-int cmd_disable( int argc, char **argv, struct mpd_connection *conn);
-
-int
-cmd_toggle_output(int argc, char **argv, struct mpd_connection *conn);
-
-int cmd_outputs(int argc, char **argv, struct mpd_connection *conn);
 int cmd_update(int argc, char **argv, struct mpd_connection *conn);
 int cmd_version(int argc, char **argv, struct mpd_connection *conn);
 int cmd_stats(int argc, char **argv, struct mpd_connection *conn);
