@@ -1,6 +1,6 @@
 /*
  * music player command (mpc)
- * Copyright (C) 2003-2015 The Music Player Daemon Project
+ * Copyright (C) 2003-2017 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,8 @@
 #define V_QUIET 0
 #define V_DEFAULT 1
 #define V_VERBOSE 2
+#define F_DEFAULT \
+    "[%name%: &[[%artist%|%performer%] - ]%title%]|%name%|[[%artist%|%performer%] - ]%title%|%file%"
 
 typedef struct {
 	const char *host;
