@@ -1,6 +1,6 @@
 /*
  * music player command (mpc)
- * Copyright (C) 2003-2013 The Music Player Daemon Project
+ * Copyright (C) 2003-2017 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -37,10 +37,8 @@ get_search_type(const char *name)
 	if (strcasecmp(name, "filename") == 0)
 		return SEARCH_TAG_URI;
 
-#if LIBMPDCLIENT_CHECK_VERSION(2,9,0)
 	if (strcasecmp(name, "base") == 0)
 		return SEARCH_TAG_BASE;
-#endif
 
 	enum mpd_tag_type type = mpd_tag_name_iparse(name);
 	if (type != MPD_TAG_UNKNOWN)
@@ -98,11 +96,9 @@ add_constraint(struct mpd_connection *conn,
 	else if (constraint->type == (enum mpd_tag_type)SEARCH_TAG_URI)
 		mpd_search_add_uri_constraint(conn, MPD_OPERATOR_DEFAULT,
 					      charset_to_utf8(constraint->query));
-#if LIBMPDCLIENT_CHECK_VERSION(2,9,0)
 	else if (constraint->type == (enum mpd_tag_type)SEARCH_TAG_BASE)
 		mpd_search_add_base_constraint(conn, MPD_OPERATOR_DEFAULT,
 					       charset_to_utf8(constraint->query));
-#endif
 	else
 		mpd_search_add_tag_constraint(conn, MPD_OPERATOR_DEFAULT,
 					      constraint->type,
@@ -129,7 +125,8 @@ add_constraints(int argc, char ** argv, struct mpd_connection *conn)
 	return true;
 }
 
-static int do_search ( int argc, char ** argv, struct mpd_connection *conn, int exact )
+static int
+do_search(int argc, char ** argv, struct mpd_connection *conn, bool exact)
 {
 	mpd_search_db_songs(conn, exact);
 	if (!add_constraints(argc, argv, conn))
@@ -145,22 +142,10 @@ static int do_search ( int argc, char ** argv, struct mpd_connection *conn, int
 	return 0;
 }
 
-int
-cmd_search(int argc, char **argv, struct mpd_connection *conn)
+static int
+do_searchadd(int argc, char **argv, struct mpd_connection *conn, bool exact)
 {
-	return do_search(argc, argv, conn, 0);
-}
-
-int
-cmd_find(int argc, char **argv, struct mpd_connection *conn)
-{
-	return do_search(argc, argv, conn, 1);
-}
-
-int
-cmd_findadd(int argc, char **argv, struct mpd_connection *conn)
-{
-	mpd_search_add_db_songs(conn, true);
+	mpd_search_add_db_songs(conn, exact);
 	if (!add_constraints(argc, argv, conn))
 		return -1;
 
@@ -170,3 +155,28 @@ cmd_findadd(int argc, char **argv, struct mpd_connection *conn)
 	my_finishCommand(conn);
 	return 0;
 }
+
+int
+cmd_search(int argc, char **argv, struct mpd_connection *conn)
+{
+	return do_search(argc, argv, conn, false);
+}
+
+
+int
+cmd_searchadd(int argc, char **argv, struct mpd_connection *conn)
+{
+	return do_searchadd(argc, argv, conn, false);
+}
+
+int
+cmd_find(int argc, char **argv, struct mpd_connection *conn)
+{
+	return do_search(argc, argv, conn, true);
+}
+
+int
+cmd_findadd(int argc, char **argv, struct mpd_connection *conn)
+{
+	return do_searchadd(argc, argv, conn, true);
+}
